Test coverage report: payslip.templatetags.payslip_tags

# payslip.templatetags.payslip_tags: 9 total statements, 100.0% covered

Generated: Sun 2014-11-09 09:00 CET

Source file: /home/tobi/Projects/django-payslip/src/payslip/templatetags/payslip_tags.py

Stats: 6 executed, 0 missed, 3 excluded, 7 ignored

1. `"""Variable filters for the ``payslip```application."""`
2. `from django.template.base import Library`
3. `from django.utils.safestring import mark_safe`
4. ``
5. `from payslip.models import ExtraField`
6. ``
7. `register = Library()`
8. ``
9. ``
10. `@register.filter(is_safe=True)`
11. `def get_extra_field_value(field_type, payment):`
12. `"""Returns the value of a specific field type."""`
13. `try:`
14. `return payment.extra_fields.get(field_type=field_type).value`
15. `except ExtraField.DoesNotExist:`
16. `return mark_safe('&nbsp;')`